@@ -141,6 +141,10 @@ class DPAPICMDHelper:
 		dpapi_describe_group.add_argument('datatype', choices = ['blob', 'masterkey', 'pvk', 'vpol', 'credential'], help= 'Type of structure')
 		dpapi_describe_group.add_argument('data', help='filepath or hex-encoded data')
 
+		dpapi_cloudapkd_group = dpapi_subparsers.add_parser('cloudapkd', help='Decrypt KeyValue structure from CloudAPK')
+		dpapi_cloudapkd_group.add_argument('mkf', help= 'Keyfile generated by the masterkey -o command.')
+		dpapi_cloudapkd_group.add_argument('keyvalue', help='KeyValue string obtained from PRT')
+
 
 	def execute(self, args):
 		if len(self.keywords) > 0 and args.command in self.keywords:
@@ -218,6 +222,10 @@ class DPAPICMDHelper:
 
 			dpapi.dump_masterkeys(args.out_file)
 
+		elif args.dapi_module == 'cloudapkd':
+			dpapi.load_masterkeys(args.mkf)
+			plain = dpapi.decrypt_cloudap_key(args.keyvalue)
+			print('Clear key: %s' % plain.hex())
 
 		elif args.dapi_module == 'credential':
 			dpapi.load_masterkeys(args.mkf)
